import { Codec, IHash } from '../types';
/**
 * @name Bool
 * @description
 * Representation for a boolean value in the system. It extends the base JS `Boolean` class
 * @noInheritDoc
 */
export default class Bool extends Boolean implements Codec {
    constructor(value?: Bool | Boolean | Uint8Array | boolean | number);
    private static decodeBool;
    /**
     * @description The length of the value when encoded as a Uint8Array
     */
    readonly encodedLength: number;
    /**
     * @description returns a hash of the contents
     */
    readonly hash: IHash;
    /**
     * @description Checks if the value is an empty value (always false)
     */
    readonly isEmpty: boolean;
    /**
     * @description Checks if the value is an empty value (always false)
     */
    readonly isFalse: boolean;
    /**
     * @description Checks if the value is an empty value (always false)
     */
    readonly isTrue: boolean;
    /**
     * @description Compares the value of the input to see if there is a match
     */
    eq(other?: any): boolean;
    /**
     * @description Returns a hex string representation of the value
     */
    toHex(): string;
    /**
     * @description Converts the Object to JSON, typically used for RPC transfers
     */
    toJSON(): boolean;
    /**
     * @description Returns the base runtime type name for this instance
     */
    toRawType(): string;
    /**
     * @description Returns the string representation of the value
     */
    toString(): string;
    /**
     * @description Encodes the value as a Uint8Array as per the SCALE specifications
     * @param isBare true when the value has none of the type-specific prefixes (internal)
     */
    toU8a(isBare?: boolean): Uint8Array;
}
